@@ -29,7 +29,7 @@
 #include <QRegExp>
 
 #include <klocale.h>
-#include <k3process.h>
+#include <KProcess>
 #include <kdebug.h>
 #include <kstandarddirs.h>
 
@@ -321,19 +321,23 @@ bool FloppyAction::configureDevice(int drive,int density)
 	return true;
 }
 
-void FloppyAction::processDone(K3Process *p)
+void FloppyAction::readStdOut()
+{
+	processStdOut( theProcess->readAllStandardOutput() );
+}
+
+void FloppyAction::readStdErr()
+{
+	processStdOut( theProcess->readAllStandardError() );
+}
+
+void FloppyAction::processDone(int exitCode, QProcess::ExitStatus exitStatus)
 {
 	DEBUGSETUP;
 
-	if (p!=theProcess)
+	if (exitStatus == QProcess::NormalExit)
 	{
-		DEBUGS("  Strange process exited.");
-		return;
-	}
-
-	if (p->normalExit())
-	{
-	        if (p->exitStatus() == 0)
+	        if (exitCode == 0)
 	        {
 			emit status(QString::null,100);	//krazy:exclude=nullstrassign for old broken gcc
 			emit done(this,true);
@@ -351,32 +355,31 @@ void FloppyAction::processDone(K3Process *p)
 	}
 }
 
-void FloppyAction::processStdOut(K3Process *, char *b, int l)
+void FloppyAction::processStdOut(const QString &s)
 {
-	Q_UNUSED(b);
-	Q_UNUSED(l);
-	kDebug(KFAREA) << "stdout:" << QString::fromLatin1(b,l) ;
+	kDebug(KFAREA) << "stdout:" << s;
 }
 
-void FloppyAction::processStdErr(K3Process *p, char *b, int l)
+void FloppyAction::processStdErr(const QString &s)
 {
-	processStdOut(p,b,l);
+	processStdOut(s);
 }
 
 bool FloppyAction::startProcess()
 {
 	DEBUGSETUP;
 
-	connect(theProcess,SIGNAL(processExited(K3Process*)),
-		this,SLOT(processDone(K3Process*)));
-	connect(theProcess,SIGNAL(receivedStdout(K3Process*,char*,int)),
-		this,SLOT(processStdOut(K3Process*,char*,int)));
-	connect(theProcess,SIGNAL(receivedStderr(K3Process*,char*,int)),
-		this,SLOT(processStdErr(K3Process*,char*,int)));
+	connect(theProcess, SIGNAL(finished(int, QProcess::ExitStatus)),
+		this, SLOT(processDone(int, QProcess::ExitStatus)));
+	connect(theProcess, SIGNAL(readyReadStandardOutput()),
+		this, SLOT(readStdOut()));
+	connect(theProcess, SIGNAL(readyReadStandardError()),
+		this, SLOT(readStdErr()));
 
-        theProcess->setEnvironment( QLatin1String( "LC_ALL" ), QLatin1String( "C" ) ); // We need the untranslated output of the tool
-	return theProcess->start(K3Process::NotifyOnExit,
-		K3Process::AllOutput);
+	theProcess->setEnv( QLatin1String( "LC_ALL" ), QLatin1String( "C" ) ); // We need the untranslated output of the tool
+	theProcess->setOutputChannelMode(KProcess::SeparateChannels);
+	theProcess->start();
+	return (theProcess->exitStatus() == QProcess::NormalExit);
 }
 
 
@@ -422,7 +425,7 @@ bool FDFormat::configure(bool v)
 	}
 
 	delete theProcess;
-	theProcess = new K3Process;
+	theProcess = new KProcess;
 
 	formatTrackCount=0;
 
@@ -461,10 +464,9 @@ bool FDFormat::configure(bool v)
 // need, since the messages can be standardized across OSsen.
 //
 //
-void FDFormat::processStdOut(K3Process *, char *b, int l)
+void FDFormat::processStdOut(const QString &s)
 {
 	DEBUGSETUP;
-	QString s;
 
 #ifdef ANY_BSD
 	if (b[0]=='F')
@@ -479,7 +481,6 @@ void FDFormat::processStdOut(K3Process *, char *b, int l)
 	}
 	else
 	{
-		s = QString::fromLatin1(b,l);
 		if (s.contains(QLatin1String( "ioctl(FD_FORM)" )))
 		{
                     emit status (i18n(
@@ -496,7 +497,6 @@ void FDFormat::processStdOut(K3Process *, char *b, int l)
 		DEBUGS(s);
 	}
 #elif defined(ANY_LINUX)
-	s = QString::fromLatin1(b,l);
 	DEBUGS(s);
         QRegExp regexp( QLatin1String( "([0-9]+)" ) );
         if ( s.startsWith( QLatin1String( "bad data at cyl" ) ) || s.contains( QLatin1String( "Problem reading cylinder" ) ) )
@@ -583,7 +583,7 @@ DDZeroOut::DDZeroOut(QObject *p) :
     }
 
     delete theProcess;
-    theProcess = new K3Process;
+    theProcess = new KProcess;
 
     *theProcess << m_ddName ;
 
@@ -598,15 +598,12 @@ DDZeroOut::DDZeroOut(QObject *p) :
 
 }
 
-void DDZeroOut::processDone(K3Process *p)
+void DDZeroOut::processDone(int exitCode, QProcess::ExitStatus exitStatus)
 {
-    kDebug(KFAREA) << k_funcinfo ;
+    Q_UNUSED(exitCode);
+    Q_UNUSED(exitStatus);
 
-    if (p!=theProcess)
-    {
-            kDebug(KFAREA) << "Strange process exited." ;
-            return;
-    }
+    kDebug(KFAREA) << k_funcinfo ;
 
     /**
      * As we do not give a number of blocks to dd(1), it will stop
@@ -680,7 +677,7 @@ void FATFilesystem::exec()
 	}
 
 	delete theProcess;
-	K3Process *p = theProcess = new K3Process;
+	KProcess *p = theProcess = new KProcess;
 
 	*p << newfs_fat;
 #ifdef ANY_BSD
@@ -710,14 +707,13 @@ void FATFilesystem::exec()
 	}
 }
 
-void FATFilesystem::processStdOut(K3Process *, char *b, int l)
+void FATFilesystem::processStdOut(const QString &s)
 {
 #ifdef ANY_BSD
     // ### TODO: do some checks
 #elif defined(ANY_LINUX)
-    QString s ( QString::fromLatin1( b, l ) );
     kDebug(KFAREA) << s ;
-    if (s.contains(QLatin1String( "mounted file system" ))) // "/dev/fd0 contains a mounted file system
+    if (s.contains(QLatin1String( "mounted" ))) // "/dev/fd0 contains a mounted filesystem"
     {
         emit status(i18n("Floppy is mounted.\nYou need to unmount the floppy first."),-1);
         return;
@@ -779,7 +775,7 @@ void UFSFilesystem::exec()
 	}
 
 	delete theProcess;
-	K3Process *p = theProcess = new K3Process;
+	KProcess *p = theProcess = new KProcess;
 
 	*p << newfs;
 
@@ -857,7 +853,7 @@ void Ext2Filesystem::exec()
 	}
 
 	delete theProcess;
-	K3Process *p = theProcess = new K3Process;
+	KProcess *p = theProcess = new KProcess;
 
 	*p << newfs;
 	*p << "-q";
@@ -873,12 +869,11 @@ void Ext2Filesystem::exec()
 	}
 }
 
-void Ext2Filesystem::processStdOut(K3Process *, char *b, int l)
+void Ext2Filesystem::processStdOut(const QString &s)
 {
 #ifdef ANY_BSD
     // ### TODO: do some checks
 #elif defined(ANY_LINUX)
-    QString s ( QString::fromLatin1( b, l ) );
     kDebug(KFAREA) << s ;
     if (s.contains(QLatin1String( "mounted" ))) // "/dev/fd0 is mounted; will not make a filesystem here!"
     {
@@ -951,7 +946,7 @@ void MinixFilesystem::exec()
 	}
 
 	delete theProcess;
-	K3Process *p = theProcess = new K3Process;
+	KProcess *p = theProcess = new KProcess;
 
 	*p << newfs;
 
@@ -967,9 +962,8 @@ void MinixFilesystem::exec()
 	}
 }
 
-void MinixFilesystem::processStdOut(K3Process *, char *b, int l)
+void MinixFilesystem::processStdOut(const QString &s)
 {
-    QString s ( QString::fromLatin1( b, l ) );
     kDebug(KFAREA) << s ;
     if (s.contains(QLatin1String( "mounted" ))) // "mkfs.minix: /dev/fd0 is mounted; will not make a filesystem here!"
     {
